Index — skope_rules 0.1.0 documentation

# Index

D | F | P | R | S

## D

decision_function() (skrules.skope_rules.SkopeRules method)

## F

fit() (skrules.skope_rules.SkopeRules method)

## P

predict() (skrules.skope_rules.SkopeRules method) | predict_top_rules() (skrules.skope_rules.SkopeRules method)

## R

rules_vote() (skrules.skope_rules.SkopeRules method)

## S

score_top_rules() (skrules.skope_rules.SkopeRules method) | SkopeRules (class in skrules.skope_rules) skrules.skope_rules (module)